# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

%bcond_without network_tests

Name:		perl-Test-Kwalitee-Extra
Version:	0.4.0
Release:	20.%{__distinit}%{__distvers}
Summary:	Run Kwalitee tests including optional indicators
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-Kwalitee-Extra
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Kwalitee-Extra-v%{version}.tar.gz
Patch0:		Test-Kwalitee-Extra-v0.4.0-CPAN128602.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Carp)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(MetaCPAN::Client)
BuildRequires:	perl(Module::CoreList) > 2.31
BuildRequires:	perl(Module::CPANTS::Analyse) >= 0.87
BuildRequires:	perl(Module::CPANTS::Kwalitee::Prereq)
BuildRequires:	perl(Module::Extract::Namespaces)
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(version) >= 0.77
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(blib)
BuildRequires:	perl(English)
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(FindBin)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(lib)
BuildRequires:	perl(Module::CPANTS::Kwalitee)
BuildRequires:	perl(Term::ANSIColor)
BuildRequires:	perl(Test::Builder::Tester)
BuildRequires:	perl(Test::More)
# Author/Release Tests
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
CPANTS checks Kwalitee indicators, which is not quality but
automatically-measurable indicators of how good your distribution is.
Module::CPANTS::Analyse calculates Kwalitee but it is not directly applicable
to your module test. CPAN has already had Test::Kwalitee for the test module of
Kwalitee. It is, however, impossible to calculate prereq_matches_use indicator,
because dependent module Module::CPANTS::Analyse itself cannot calculate
prereq_matches_use indicator. It is marked as needs_db, but only limited
information is needed to calculate the indicator. This module calculates
prereq_matches_use by querying needed information from MetaCPAN.

%prep
%setup -q -n Test-Kwalitee-Extra-v%{version}

# Work around issues with M:C:A 1.00 (CPAN RT#128602)
%patch -P 0

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
%if !%{with network_tests}
mv t/{01-kwalitee,04-prereq_maches_use,05-build_prereq_matches_use,06-minperlver}.t ./
%endif

make test AUTHOR_TESTING=1 RELEASE_TESTING=1

%if !%{with network_tests}
mv ./{01-kwalitee,04-prereq_maches_use,05-build_prereq_matches_use,06-minperlver}.t t/
%endif

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Kwalitee::Extra.3*

%changelog
* Thu May 25 2023 Paul Howarth <paul@city-fan.org> - 0.4.0-20
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax
- Use %%license unconditionally

* Tue Mar 10 2020 Paul Howarth <paul@city-fan.org> - 0.4.0-11
- BR: perl(blib) for t/00-compile.t

* Tue Sep  3 2019 Paul Howarth <paul@city-fan.org> - 0.4.0-7
- Switch upstream from search.cpan.org to metacpan.org
- Work around issues with M:C:A 1.00 (CPAN RT#128602)

* Mon Apr  9 2018 Paul Howarth <paul@city-fan.org> - 0.4.0-3
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jun 25 2017 Paul Howarth <paul@city-fan.org> - 0.4.0-1
- Update to 0.4.0
  - Only search existing directories
  - Use MetaCPAN::Client rather than MetaCPAN::API::Tiny

* Wed Jun 14 2017 Paul Howarth <paul@city-fan.org> - 0.3.1-5
- Add ability to disable at build-time the tests that require external network
  access (--without network_tests)
- Disable network tests for now as MetaCPAN::API::Tiny is using a no longer
  supported API (CPAN RT#122004)
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Mon Jan  9 2017 Paul Howarth <paul@city-fan.org> - 0.3.1-4
- Add support for older distributions now that dependencies are available

* Sat Oct  1 2016 Paul Howarth <paul@city-fan.org> - 0.3.1-3
- BR: perl-generators where available
- Simplify find command using -delete

* Tue Aug 11 2015 Paul Howarth <paul@city-fan.org> - 0.3.1-1
- Update to 0.3.1
  - Fix false alarm for warnings (GH#20, CPAN RT#104113)
  - Fix minor grammatical error in error message

* Tue Sep  9 2014 Paul Howarth <paul@city-fan.org> - 0.3.0-1
- Update to 0.3.0
  - Adopt to new stash layout of Module::CPANTS::Analyse since 0.93_01 (GH#19)
- Use %%license where possible

* Sun Mar 30 2014 Paul Howarth <paul@city-fan.org> - 0.2.1-1
- Update to 0.2.1
  - Add explicit caution and workaround for network access in POD (GH #17)

* Thu Feb  6 2014 Paul Howarth <paul@city-fan.org> - 0.2.0-1
- Initial RPM version
